@@ -13,8 +13,8 @@
 
 #define OUTLINE_SHADE 0.5
 
-#define CRUX_LIGHT(xx, yy) ge_shade_color (&xx, 1.5, &yy)//yy.r = xx.r + 56/255.0;yy.g = xx.g + 47/255.0;yy.b = xx.b + 45/255.0;
-#define CRUX_DARK(xx, yy) ge_shade_color (&xx, 0.9, &yy)//yy.r = xx.r - 25/255.0;yy.g = xx.g - 27/255.0;yy.b = xx.b - 21/255.0;
+#define CRUX_LIGHT(xx, yy) ge_shade_color (&xx, 1.5, &yy) /* yy.r = xx.r + 56/255.0;yy.g = xx.g + 47/255.0;yy.b = xx.b + 45/255.0; */
+#define CRUX_DARK(xx, yy) ge_shade_color (&xx, 0.9, &yy) /* yy.r = xx.r - 25/255.0;yy.g = xx.g - 27/255.0;yy.b = xx.b - 21/255.0; */
 
 static GtkStyleClass *parent_style_class;
 
