@@ -46,7 +46,7 @@ hc_draw_shadow(GtkStyle * style,
 	       gint height)
 {
 	/* Border Uses Foreground Color */
-	CairoColor *foreground = &HC_STYLE(style)->color_cube.fg[state_type];
+	CairoColor foreground = HC_STYLE(style)->color_cube.fg[state_type];
 
 	gint line_width;
 	gint clip_x = x, clip_y = y, clip_width = width, clip_height = height;
@@ -97,10 +97,9 @@ hc_draw_shadow(GtkStyle * style,
 		}
 
 		/* Force Border To Use Foreground Widget State */
-		if ((widget) && (widget->parent))
+		if (widget)
 		{
-	               	gtk_widget_ensure_style(widget);
-			foreground = &HC_STYLE(widget->style)->color_cube.fg[widget->state];
+			foreground = HC_STYLE(style)->color_cube.fg[widget->state];
 		}
 	}
 
@@ -108,9 +107,7 @@ hc_draw_shadow(GtkStyle * style,
 	/* Entry - Force Border To Use Foreground Matching Widget State */
 	if (CHECK_DETAIL(detail, "entry") && !ge_is_combo(widget))
 	{
-               	gtk_widget_ensure_style(widget);
-
-		foreground = &HC_STYLE(style)->color_cube.fg[widget ? widget->state : GTK_STATE_NORMAL];
+		foreground = HC_STYLE(style)->color_cube.fg[widget ? widget->state : GTK_STATE_NORMAL];
 	}
 
 
@@ -132,8 +129,8 @@ hc_draw_shadow(GtkStyle * style,
 		/* Force Border To Use Foreground Matching Parent State */
 		if ((widget) && (widget->parent))
 		{
-	               	gtk_widget_ensure_style(widget->parent);
-			foreground = &HC_STYLE(widget->parent->style)->color_cube.fg[widget->parent->state];
+			gtk_widget_ensure_style(widget->parent);
+			ge_gdk_color_to_cairo(&widget->parent->style->fg[GTK_WIDGET_STATE(widget)], &foreground);
 		}
 	}
 
@@ -148,7 +145,7 @@ hc_draw_shadow(GtkStyle * style,
 	cairo_clip(canvas);
 
 	/* Set Line Style */
-	ge_cairo_set_color(canvas, foreground);
+	ge_cairo_set_color(canvas, &foreground);
 	cairo_set_line_cap(canvas, CAIRO_LINE_CAP_BUTT);
 
 	/* Pixel Alignedness -
@@ -159,8 +156,7 @@ hc_draw_shadow(GtkStyle * style,
 	cairo_set_line_width (canvas, line_width + ((line_width%2)?1.0:0.5));
 
 	/* Stroke Rectangle */
-	cairo_rectangle (canvas, x, y, width, height);
-	cairo_stroke(canvas);
+	ge_cairo_stroke_rectangle (canvas, x, y, width, height);
 
 	cairo_destroy(canvas);
 }
@@ -231,8 +227,7 @@ hc_draw_shadow_gap (GtkStyle       *style,
 	cairo_set_line_width (canvas, line_width + ((line_width%2)?1.0:0.5));
 
 	/* Stroke Rectangle */
-	cairo_rectangle (canvas, x, y, width, height);
-	cairo_stroke(canvas);
+	ge_cairo_stroke_rectangle (canvas, x, y, width, height);
 
 	cairo_destroy(canvas);
 }
@@ -377,8 +372,7 @@ hc_draw_extension (GtkStyle       *style,
 	cairo_set_line_width (canvas, line_width + ((line_width%2)?1.0:0.5));
 
 	/* Stroke Rectangle */
-	cairo_rectangle (canvas, x, y, width, height);
-	cairo_stroke(canvas);
+	ge_cairo_stroke_rectangle (canvas, x, y, width, height);
 
 	cairo_destroy(canvas);
 }
@@ -593,13 +587,15 @@ hc_draw_handle (GtkStyle      *style,
 	}
 	else
 	{
-		for (yy = y + ythick; yy < (y + height - ythick); yy += 3)
+		if (orientation == GTK_ORIENTATION_HORIZONTAL)
 		{
-			for (xx = x + xthick; xx < (x + width - xthick); xx += 6)
-			{
-				do_hc_draw_dot (canvas, light, dark, xx, yy);
-				do_hc_draw_dot (canvas, light, dark, xx + 3, yy + 1);
-			}
+			for (xx = x + xthick + (width/2 - xthick) % 5; xx <= x + width - xthick*2; xx += 5)
+				do_hc_draw_dot (canvas, light, dark, xx + 2, y + height/2);
+		}
+		else
+		{
+			for (yy = y + ythick + (height/2 - ythick) % 5; yy <= y + height - ythick*2; yy += 5)
+				do_hc_draw_dot (canvas, light, dark, x + width/2, yy + 2);
 		}
 	}
 
@@ -694,7 +690,7 @@ hc_draw_check (GtkStyle      *style,
 		height = HC_STYLE(style)->cell_indicator_size;
 	}
 	
-	inconsistent = ge_toggle_get_inconsistent(widget, detail, shadow_type);
+	inconsistent = (shadow_type == GTK_SHADOW_ETCHED_IN);
 
 	line_width = ceil(HC_STYLE(style)->edge_thickness/2);
 	cr = ge_gdk_drawable_to_cairo (window, area);
@@ -719,8 +715,7 @@ hc_draw_check (GtkStyle      *style,
 	cairo_set_line_width (cr, line_width + ((line_width%2)?1.0:0.5));
 
 	/* Stroke Rectangle */
-	cairo_rectangle (cr, x, y, width, height);
-	cairo_stroke(cr);
+	ge_cairo_stroke_rectangle (cr, x, y, width, height);
 
 	cairo_restore(cr);
 
@@ -825,42 +820,39 @@ hc_draw_option (GtkStyle      *style,
 	cairo_set_line_width (cr, radius*0.30);
 	cairo_set_line_cap(cr, CAIRO_LINE_CAP_BUTT);
 	
-	cairo_arc(cr, centerX, centerY, radius, 0 , 2 * M_PI);
+	cairo_arc(cr, centerX, centerY, radius, 0 , 2 * G_PI);
 	ge_cairo_set_color(cr, &hc_style->color_cube.bg[state_type]);	
 	cairo_fill (cr);
 
-	cairo_arc(cr, centerX, centerY, radius, 0 , 2 * M_PI);
+	cairo_arc(cr, centerX, centerY, radius, 0 , 2 * G_PI);
 	ge_cairo_set_color(cr, &hc_style->color_cube.fg[state_type]);	
 	cairo_stroke (cr);
 
-	inconsistent = ge_toggle_get_inconsistent(widget, detail, shadow_type);
+	inconsistent = (shadow_type == GTK_SHADOW_ETCHED_IN);
 
-	if ((shadow_type == GTK_SHADOW_IN) || inconsistent)
+	ge_cairo_set_color(cr, &hc_style->color_cube.text[state_type]);
+
+	if (shadow_type == GTK_SHADOW_IN)
 	{
-		ge_cairo_set_color(cr, &hc_style->color_cube.text[state_type]);	
+		cairo_arc(cr, centerX, centerY, radius*0.38, 0, 2 * G_PI);
+		cairo_fill(cr);
+		cairo_arc(cr, centerX, centerY, radius*0.38, 0, 2 * G_PI);
+		cairo_stroke(cr);
+	}
+	else if (inconsistent)
+	{
+		int line_width = ceil(radius*0.68);
 
-		if (inconsistent)
-		{
-			int line_width = ceil(radius*0.68);
+		/* Force Thickness Even */
+		line_width -= (line_width % 2);
 
-			/* Force Thickness Even */
-			line_width -= (line_width % 2);
+		cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND);
+		cairo_set_line_width (cr, line_width);
 
-			cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND);
-			cairo_set_line_width (cr, line_width);
+		cairo_move_to(cr, centerX - radius*0.38, centerY);
+		cairo_line_to(cr, centerX + radius*0.38, centerY);
 
-			cairo_move_to(cr, centerX - radius*0.38, centerY);
-			cairo_line_to(cr, centerX + radius*0.38, centerY);
-
-			cairo_stroke (cr);
-		}
-		else
-		{
-			cairo_arc(cr, centerX, centerY, radius*0.38, 0, 2 * M_PI);
-			cairo_fill(cr);
-			cairo_arc(cr, centerX, centerY, radius*0.38, 0, 2 * M_PI);
-			cairo_stroke(cr);
-		}
+		cairo_stroke (cr);
 	}
 
 	cairo_destroy(cr);
@@ -1335,8 +1327,8 @@ hc_draw_polygon (GtkStyle      *style,
 {
 	HcStyle *hc_style = HC_STYLE (style);
 
-	static const gdouble pi_over_4 = M_PI_4;
-	static const gdouble pi_3_over_4 = M_PI_4 * 3;
+	static const gdouble pi_over_4 = G_PI_4;
+	static const gdouble pi_3_over_4 = G_PI_4 * 3;
 	
 	CairoColor           *color1;
 	CairoColor           *color2;
